{ inputs, pkgs, ...}: {
  nixpkgs.config.allowUnfree = true;
  nix.settings.trusted-users = [ "root" "@wheel" ];
  nix.registry.nixpkgs.flake = inputs.nixpkgs;
  nix.extraOptions = ''
    experimental-features = nix-command flakes
  '';
  nix.gc = {
    automatic = true;
    options = "--delete-older-than 21d";
  };

  security.sudo.wheelNeedsPassword = false;
  services.openssh = {
    enable = true;
    settings = {
      PasswordAuthentication = false;
      KbdInteractiveAuthentication = false;
      PermitRootLogin = "prohibit-password";
    };
  };
  environment.shellAliases = {
    "lah" = "ls --color=auto -lah";
  };
  environment.variables = {
    EDITOR = "vim";
    VISUAL = "vim";
  };
  environment.systemPackages = with pkgs; [
    python3
    vim
    tmux
    jq
    yq
    tree
    git
    bind.dnsutils
    openssl
    curl
    wget
    htop
    usbutils
    pciutils
  ];
}
